# coding=utf-8
"""
Simulador Integral de Cadenas Productivas (SICP)

Copyleft (@) 2015 CENDITEL nodo Mérida - https://miv.cenditel.gob.ve/simulacion/
"""
## @package sicp.settings
#
# Configuración de funcionalidades y parámetros del sistema
# @author Generated by 'django-admin startproject' using Django 1.8.
# @author Ing. Roldan Vargas (rvargas at cenditel.gob.ve)
# @author <a href='http://www.cenditel.gob.ve'>Centro Nacional de Desarrollo e Investigación en Tecnologías Libres
# (CENDITEL) nodo Mérida - Venezuela</a>
# @copyright <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU Public License versión 2 (GPLv2)</a>
# @version 3.0.0

# Django settings for sicp project.
# Generated by 'django-admin startproject' using Django 1.8.
# For more information on this file, see https://docs.djangoproject.com/en/1.8/topics/settings/
# For the full list of settings and their values, see https://docs.djangoproject.com/en/1.8/ref/settings/

## Muestra el autor del script cuando es invocado
__author__ = "Generated by 'django-admin startproject' using Django 1.8."
## Muestra documentación breve sobre el script
__doc__    = "Configuración de funcionalidades y parámetros del sistema"

from database_config import DATABASES_CONFIG
import os

## Directorio base desde donde se encuentra ejecutando la aplicación
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

## Número de versión de la aplicación
VERSION = '3.0.0'


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.8/howto/deployment/checklist/

## Clave secreta del sistema
SECRET_KEY = 'exdo%=40*1ry3g2$nyi@oq-i+f^#q0_ksz(kd969^)y=#!zj7('

## Identifica si el sistema se encuentra en modo de desarrollo (True) o en modo producción (False)
DEBUG = True

## Listado de Hosts permitidos por el sistema
ALLOWED_HOSTS = ['localhost']

INTERNAL_IPS = (AH for AH in ALLOWED_HOSTS)

## Listado de aplicaciones cargadas por el sistema
INSTALLED_APPS = (
    'suit',  # Modern theme for Django admin interface
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.humanize',
    'django_extensions', # Opcional, no requerido para el funcionamiento del sistema
    'wkhtmltopdf', # app para generar reportes en pdf a partir de un html
    'captcha',
    'apps.comun',
    'apps.usuario',
    'apps.simulacion',
    'apps.simulacion.sigesic',
    'apps.simulacion.encuesta',
    'apps.simulacion.matrizip'
)

## Listado de clases middleware
MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django.middleware.security.SecurityMiddleware',
    'django.middleware.locale.LocaleMiddleware'
)

## Configuración de las URL del sistema
ROOT_URLCONF = 'sicp.urls'

## Directorio en donde se encuentran las plantillas base
BASE_TEMPLATES = os.path.join(BASE_DIR, "templates")

## Directorio en donde se encuentran las plantillas para la simulación de escenarios
SIMULACION_TEMPLATES = os.path.join(BASE_DIR, "apps/simulacion/templates")

## Directorio en donde se encuentran las plantillas del sigesic
SIGESIC_TEMPLATES = os.path.join(BASE_DIR, "apps/simulacion/sigesic/templates")

## Directorio en donde se encuentran las plantillas de la encuesta industrial
ENCUESTA_TEMPLATES = os.path.join(BASE_DIR, "apps/simulacion/encuesta/templates")

## Configuración de plantillas del sistema
TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [BASE_TEMPLATES, SIMULACION_TEMPLATES, SIGESIC_TEMPLATES, ENCUESTA_TEMPLATES],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ]
        },
    },
]

## Configuración para el wsgi de la aplicación
WSGI_APPLICATION = 'sicp.wsgi.application'

## Configuración de la(s) base(s) de dato(s) del sistema
DATABASES = DATABASES_CONFIG

## Configuración del código del lenguaje a utilizar por defecto
LANGUAGE_CODE = 'es-ve'

## Configuración para el nombre de localización por defecto
LOCALE_NAME = 'es'

## Configuración para la zona horaria por defecto
TIME_ZONE = 'UTC'

## Determina si se emplea la internacionalización I18N
USE_I18N = True

## Determina si se emplea la internacionalización L10N
USE_L10N = True

## Determina si se emplea la zona horaria
USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.8/howto/static-files/

## Configuración de la raíz donde se encuentran los archivos estaticos del sistema (para entornos en producción)
STATIC_ROOT = ''

## Configuración de la url que atenderá las peticiones de los archivos estáticos del sistema
STATIC_URL = '/static/'

## Configuración de los directorios en donde se encuentran los archivos estáticos
STATICFILES_DIRS = (
    os.path.join(BASE_DIR, 'static/'),
    os.path.join(BASE_DIR, 'tmp/'),
    # Directorios en los cuales buscar archivos estaticos en produccion, en caso de ubicar los archivos estáticos en
    # otro directorio, se debe agregar la ruta
    '/var/www/html/sicp/static/',
)

## Configuración que permite buscar distintas ubicaciones de archivos estáticos
STATICFILES_FINDER = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
)

## URL de acceso al sistema
LOGIN_URL = "/login"
## URL de salida del sistema
LOGOUT_URL = "/logout"

## configuración que permite obtener la ruta en donde se encuentran las traducciones de la aplicación a otros lenguajes
LOCALE_PATHS = (
    os.path.join(BASE_DIR, 'locale'),
)

## Registro de mensajes al usuario
MESSAGE_STORAGE = 'django.contrib.messages.storage.cookie.CookieStorage'

## Parámetros de configuración del panel administrativo del sistema
SUIT_CONFIG = {
    # header
    'ADMIN_NAME': 'SICP v%s' % VERSION,
    'HEADER_DATE_FORMAT': 'l, d F Y',
    'HEADER_TIME_FORMAT': 'h:i a',

    'LIST_PER_PAGE': 15,
}

# Configuración de variables para el envío de correo electrónico
## Nombre del Servidor de correo SMTP
EMAIL_HOST = 'localhost'
## Puerto del Servfidor de correo SMTP
EMAIL_PORT = 25
## Dirección de correo electrónico del Simulador Integral de Cadenas Productivas
EMAIL_FROM = 'sicp@cenditel.gob.ve'
## Dirección de correo electrónico del Servidor
#SERVER_EMAIL = 'sicp@cenditel.gob.ve'
## Dirección de correo electrónico por defecto
#DEFAULT_FROM_EMAIL = 'sicp@cenditel.gob.ve'

## Registro de vitácoras de errores (logs)
LOGS_PATH = '/var/log/sicp'

## Configuración de los niveles de vitácoras (logs) a registrar
LOGGING = dict(version=1, disable_existing_loggers=True, formatters={
    'std': {
        'format': '%(asctime)s %(levelname)-8s [modulo: %(module)s, funcion: %(funcName)s, linea: %(lineno)d]. %(message)s',
    }
}, handlers={
    'null': {
        'level': 'DEBUG',
        'class': 'django.utils.log.NullHandler'
    },
    'comun': {
        'class': 'logging.handlers.TimedRotatingFileHandler',
        'level': 'DEBUG',
        'formatter': 'std',
        'filename': os.path.join(LOGS_PATH, 'comun.log'),
        'when': 'w6',
        'interval': 1,
        'backupCount': 52
    },
    'usuario': {
        'class': 'logging.handlers.TimedRotatingFileHandler',
        'level': 'DEBUG',
        'formatter': 'std',
        'filename': os.path.join(LOGS_PATH, 'usuario.log'),
        'when': 'w6',
        'interval': 1,
        'backupCount': 52
    },
    'simulacion': {
        'class': 'logging.handlers.TimedRotatingFileHandler',
        'level': 'DEBUG',
        'formatter': 'std',
        'filename': os.path.join(LOGS_PATH, 'simulacion.log'),
        'when': 'w6',
        'interval': 1,
        'backupCount': 52
    },
    'sigesic': {
        'class': 'logging.handlers.TimedRotatingFileHandler',
        'level': 'DEBUG',
        'formatter': 'std',
        'filename': os.path.join(LOGS_PATH, 'sigesic.log'),
        'when': 'w6',
        'interval': 1,
        'backupCount': 52
    },
    'encuesta': {
        'class': 'logging.handlers.TimedRotatingFileHandler',
        'level': 'DEBUG',
        'formatter': 'std',
        'filename': os.path.join(LOGS_PATH, 'encuesta.log'),
        'when': 'w6',
        'interval': 1,
        'backupCount': 52
    },
    'matrizip': {
        'class': 'logging.handlers.TimedRotatingFileHandler',
        'level': 'DEBUG',
        'formatter': 'std',
        'filename': os.path.join(LOGS_PATH, 'matrizip.log'),
        'when': 'w6',
        'interval': 1,
        'backupCount': 52
    }
}, loggers={
    'root': {
        'level': 'DEBUG',
        'handlers': ['usuario']
    },
    'comun': {
        'level': 'DEBUG',
        'handlers': ['comun'],
        'qualname': 'comun'
    },
    'usuario': {
        'level': 'DEBUG',
        'handlers': ['usuario'],
        'qualname': 'usuario'
    },
    'simulacion': {
        'level': 'DEBUG',
        'handlers': ['simulacion'],
        'qualname': 'simulacion'
    },
    'sigesic': {
        'level': 'DEBUG',
        'handlers': ['sigesic'],
        'qualname': 'sigesic'
    },
    'encuesta': {
        'level': 'DEBUG',
        'handlers': ['encuesta'],
        'qualname': 'encuesta'
    },
    'matrizip': {
        'level': 'DEBUG',
        'handlers': ['matrizip'],
        'qualname': 'matrizip'
    },
    'django.request': {
        'handlers': ['null'],
        'level': 'ERROR',
        'propagate': False,
    }
})

# Configuración del CAPTCHA
## Ruta en donde se encuentra el diccionario de palabras a utilizar en la generación del captcha
CAPTCHA_WORDS_DICTIONARY = os.path.join(BASE_DIR, "static/dictionaries/captcha-es.txt")
## Establece el tipo de captcha a generar. Se establece a la extraccion de palabras a partir de un diccionario
CAPTCHA_CHALLENGE_FUNCT = 'captcha.helpers.word_challenge'
## Longitud de carácteres a mostrar en la imagen del captcha
CAPTCHA_LENGTH = 6
## Longitud de carácteres máxima permitida para extraer del diccionario
CAPTCHA_DICTIONARY_MAX_LENGTH = 6
## Longitud de carácteres mínima permitida para extraer del diccionario
CAPTCHA_DICTIONARY_MIN_LENGTH = 4
## Color de fondo para la imagen del captcha
CAPTCHA_BACKGROUND_COLOR = '#337AB7'
## Color de la fuente para la imagen del captcha
CAPTCHA_FOREGROUND_COLOR = '#FFF'

if DEBUG:
    ## Elimina la imagen de ruido en el fondo del captcha cuando la aplicacion se encuentra en modo desarrollo
    CAPTCHA_NOISE_FUNCTIONS = ('captcha.helpers.noise_null',)
